<?php

/**
 * Do not edit anything in this file unless you know what you're doing
 */

use Roots\Sage\Config;
use Roots\Sage\Container;

/**
 * Helper function for prettying up errors
 * @param string $message
 * @param string $subtitle
 * @param string $title
 */
$sage_error = function ($message, $subtitle = '', $title = '') {
    $title = $title ?: __('Sage &rsaquo; Error', 'sage');
    $footer = '<a href="https://roots.io/sage/docs/">roots.io/sage/docs/</a>';
    $message = "<h1>{$title}<br><small>{$subtitle}</small></h1><p>{$message}</p><p>{$footer}</p>";
    wp_die($message, $title);
};

/**
 * Ensure compatible version of PHP is used
 */
if (version_compare('7.1', phpversion(), '>=')) {
    $sage_error(__('You must be using PHP 7.1 or greater.', 'sage'), __('Invalid PHP version', 'sage'));
}

/**
 * Ensure compatible version of WordPress is used
 */
if (version_compare('4.7.0', get_bloginfo('version'), '>=')) {
    $sage_error(__('You must be using WordPress 4.7.0 or greater.', 'sage'), __('Invalid WordPress version', 'sage'));
}

/**
 * Ensure dependencies are loaded
 */
if (!class_exists('Roots\\Sage\\Container')) {
    if (!file_exists($composer = __DIR__.'/../vendor/autoload.php')) {
        $sage_error(
            __('You must run <code>composer install</code> from the Sage directory.', 'sage'),
            __('Autoloader not found.', 'sage')
        );
    }
    require_once $composer;
}

/**
 * Sage required files
 *
 * The mapped array determines the code library included in your theme.
 * Add or remove files to the array as needed. Supports child theme overrides.
 */
array_map(function ($file) use ($sage_error) {
    $file = "../app/{$file}.php";
    if (!locate_template($file, true, true)) {
        $sage_error(sprintf(__('Error locating <code>%s</code> for inclusion.', 'sage'), $file), 'File not found');
    }
}, ['helpers', 'setup', 'filters', 'admin','walker']);

/**
 * Here's what's happening with these hooks:
 * 1. WordPress initially detects theme in themes/sage/resources
 * 2. Upon activation, we tell WordPress that the theme is actually in themes/sage/resources/views
 * 3. When we call get_template_directory() or get_template_directory_uri(), we point it back to themes/sage/resources
 *
 * We do this so that the Template Hierarchy will look in themes/sage/resources/views for core WordPress themes
 * But functions.php, style.css, and index.php are all still located in themes/sage/resources
 *
 * This is not compatible with the WordPress Customizer theme preview prior to theme activation
 *
 * get_template_directory()   -> /srv/www/example.com/current/web/app/themes/sage/resources
 * get_stylesheet_directory() -> /srv/www/example.com/current/web/app/themes/sage/resources
 * locate_template()
 * ├── STYLESHEETPATH         -> /srv/www/example.com/current/web/app/themes/sage/resources/views
 * └── TEMPLATEPATH           -> /srv/www/example.com/current/web/app/themes/sage/resources
 */
array_map(
    'add_filter',
    ['theme_file_path', 'theme_file_uri', 'parent_theme_file_path', 'parent_theme_file_uri'],
    array_fill(0, 4, 'dirname')
);
Container::getInstance()
    ->bindIf('config', function () {
        return new Config([
            'assets' => require dirname(__DIR__).'/config/assets.php',
            'theme' => require dirname(__DIR__).'/config/theme.php',
            'view' => require dirname(__DIR__).'/config/view.php',
        ]);
    }, true);


 //enqueue important styles 
function load_style() {
    $post_id = get_the_ID();
    // Register new scripts to allow using them inside blades.
    wp_register_style( 'blog-style',\App\asset_path('/styles/components/blog.css') );
    wp_register_style( 'blog-details',\App\asset_path('/styles/components/blog-details.css') );
    wp_register_style( 'category-style',\App\asset_path('/styles/components/category.css') );
    wp_register_style( 'contactUs-style',\App\asset_path('/styles/components/contactUs.css') );
    wp_register_style( '404-style',\App\asset_path('/styles/components/404.css') );
    wp_register_style( 'search-results',\App\asset_path('/styles/components/search-results.css') );

    // disable Gutenberg styles for non admin users
    if ( ! is_user_logged_in() && ! current_user_can( 'administrator' ) && ! current_user_can( 'editor' ) ) {
        wp_dequeue_style( 'wp-block-library' );
    }

    // enqueue Fontawesome library in footer
    add_action('wp_footer', function() {
        ?>
        <script>
            window.addEventListener('load', function() {
                var link = document.createElement('link');
                link.rel = 'stylesheet';
                link.href = 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css';
                document.body.appendChild(link);
            });
        </script>
        <?php
    });
    
}
add_action('wp_enqueue_scripts', 'load_style');

add_action('wp_body_open', 'Gtag_body', 1);

function Gtag_body() {
    $google_tag_id = get_field('google_tag_id', 'option') ?: 'GTM-P8ZCT6M'; // Assuming ACF field is used to store the Google Tag Manager ID
    ?>
    <!-- Google Tag Manager (noscript) -->
    <noscript><iframe src="https://www.googletagmanager.com/ns.html?id=<?php echo esc_attr($google_tag_id); ?>"
        height="0" width="0" style="display:none;visibility:hidden"></iframe></noscript>
    <!-- End Google Tag Manager (noscript) -->
    <?php
}

add_action('wp_footer', 'ft_output', 99);

function ft_output() {
    $timer_delay = '5000';
    $output = '<script>';
    $output .= "(function () {
        var loadedTLAnalytics = false,
            timerId;

        if (navigator.userAgent.indexOf('YandexMetrika') > -1) {
            loadTLAnalytics();
        } else {
            window.addEventListener('scroll', loadTLAnalytics, { passive: true });
            window.addEventListener('touchstart', loadTLAnalytics, { passive: true });
            document.addEventListener('mouseenter', loadTLAnalytics, { passive: true });
            document.addEventListener('click', loadTLAnalytics, { passive: true });
            document.addEventListener('DOMContentLoaded', loadFallback, { passive: true });
        }

        function loadFallback() {
            timerId = setTimeout(loadTLAnalytics, " . $timer_delay . ");
        }

        function loadTLAnalytics(e) {
            if (e && e.type) {
                console.log(e.type);
            } else {
                console.log('DOMContentLoaded');
            }

            if (loadedTLAnalytics) {
                return;
            }

            setTimeout(function () {
                " . FT_add_google_analytics() . "
            }, 100);

            loadedTLAnalytics = true;
            clearTimeout(timerId);
            window.removeEventListener('scroll', loadTLAnalytics, { passive: true });
            window.removeEventListener('touchstart', loadTLAnalytics, { passive: true });
            document.removeEventListener('mouseenter', loadTLAnalytics);
            document.removeEventListener('click', loadTLAnalytics);
            document.removeEventListener('DOMContentLoaded', loadFallback);
        }
    })();
    console.log('analytics in body');
    </script>";

    echo $output;
}

function FT_add_google_analytics() {
    $g_id = get_field('google_analytics_id', 'option') ?: 'G-ZVEXP49T91'; // Assuming ACF field is used to store the Google Analytics ID
    $output = '';
    if (isset($g_id) && $g_id !== '') {
        $output = '
        var analyticsId = "' . $g_id . '";
        var a = document.createElement("script");

        function e() {
            dataLayer.push(arguments);
        }

        (a.src = "https://www.googletagmanager.com/gtag/js?id=" + analyticsId),
        (a.async = !0),
        document.getElementsByTagName("head")[0].appendChild(a),
        (window.dataLayer = window.dataLayer || []),
        e("js", new Date()),
        e("config", analyticsId);
        ';
    }

    return $output;
}



// load tawk.to widgets temporary
add_action('wp_footer', function() {
    ?>
    <script src="https://cdn.jsdelivr.net/npm/ip-geolocation-api-jquery-sdk@1.1.0/ipgeolocation.min.js"></script>
    <script>
    
    // On call to IPGeolocation API on each page during a user's visit, API response will be served from sessionStorage after the first page.
    _ipgeolocation.enableSessionStorage(true);

    var ip = sessionStorage.getItem("ip");
    var country_name = sessionStorage.getItem("country_name");
    var country_code2 = sessionStorage.getItem("country_code2");
            
    if (!ip || !country_name || !country_code2) {
        _ipgeolocation.makeAsyncCallsToAPI(false);
        _ipgeolocation.setFields("country_name,country_code2");
        _ipgeolocation.getGeolocation(handleResponse, "9448d0ba101142059d8091a670dfc7d0");
    }

    function handleResponse(json) {
        ip = json.ip;
        country_name = json.country_name;
        country_code2 = json.country_code2;
    }
    
    
    var Tawk_API=Tawk_API||{}, Tawk_LoadStart=new Date();
    console.log("country = " + country_name);
    if( country_name !== undefined ){
        if( country_name === 'Egypt' ){
            // load egypt widget
            let s1=document.createElement("script"),s0=document.getElementsByTagName("script")[0];
            s1.async=true;
            s1.src='https://embed.tawk.to/5bc8ce3b460a125f2656a90b/1gt8p9u2m';
            s1.charset='UTF-8';
            s1.setAttribute('crossorigin','*');
            s0.parentNode.insertBefore(s1,s0);
            //console.log('Egypt widget loaded, ', s1.src);
        } else {
            let s2=document.createElement("script"),s3=document.getElementsByTagName("script")[0];
            s2.async=true;
            s2.src='https://embed.tawk.to/5bc8ce3b460a125f2656a90b/default';
            s2.charset='UTF-8';
            s2.setAttribute('crossorigin','*');
            s3.parentNode.insertBefore(s2,s3);
            //console.log('Default widget loaded, ', s1.src);
        }
    }
    
    document.querySelector('[arial-label="Support & Other Inquiries"]').parentElement.classList.add('support-dept');
</script>

    <?php
});    